==> hboard-1.0-rc1.tar.gz: hboard/comment.php <==
<?php

/* EtchiBoard Version 1.0
     comment.php
     http://etchibbs.kldp.net */

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

include ("lib/admin.inc"); //  ȯ漳
include ("lib/headfoot.inc"); //  /ϴ
include ("lib/list.inc"); //   function
include ("lib/message.inc"); // ޽ function

PrintHeader();

if(!$article) {
 PrintMessage("<b>Խù  ϴ.</b><br>comment.php?article=[ȣ]  Էϼ.", "error");
}
else {
?>
<center>

<Script Language="JavaScript" Type="">
function imagesel(sel)
{
var src;
src = sel.options[sel.selectedIndex].value

if(sel.options[sel.selectedIndex].value == "none.jpg") {
  src = "skin/<?=$admin_data[skin]?>/"+src
}
else {
  src = "db/ico/"+src
}

 return src;
}

function drawImage(sel,i)
{
i.src = imagesel(sel)
i.alt = "Icon Preview";
}

function checkvalue() {
		if(document.inputform.name.value == ""){
			alert("ۼ ̸  ּ.");
			document.inputform.name.focus();
			return true;
		}
		else if(document.inputform.ne.value == ""){
			alert("ǰ߱  Է ּ.");
			document.inputform.ne.focus();
			return true;
		}
		else if(document.inputform.passwd.value == ""){
			alert("йȣ Է ּ.");
			document.inputform.passwd.focus();
			return true;
		}
		else{
			document.inputform.submit();
		}
}
</Script>

<table align="center" cellpadding="0" cellspacing="0" width="640">
<tr><td width="640" height="20">
<table cellpadding="0" cellspacing="0" width="100%">
<tr><td width="17" height="25" background="skin/<?=$admin_data[skin]?>/title_bg.gif">
<p align="center">
<img src="skin/<?=$admin_data[skin]?>/write.gif" width="14" height="20" border="0" alt="write.gif">
</p></td><td width="674" height="20" background="skin/<?=$admin_data[skin]?>/title_bg.gif">
<p><font color="<?=$skin[sfont2_color]?>">&nbsp;<b><?=$article?> Խù ǰ </b></font></p>
</td></tr>
</table>
</td></tr>

<tr>
<td width="640">

<center>
<form name="inputform" target="_self" method="post" action="post_comment.php" ENCTYPE="multipart/form-data" onsubmit="this.submit_btn.disabled=true">

<input type=hidden name=article value=<?=$article?>>
<input type=hidden name=page value=<?=$page?>>

<TABLE border=1 width="639" cellspacing=0 cellpadding=7 bgcolor="<?=$skin[image_table_bgcolor]?>">
<TR ALIGN=CENTER><TD width="337">
<table border=0 cellpadding=0 cellspacing=0><tr><td>
<TABLE BORDER=0 CELLPADDING=0 CELLSPACING=0>

<TR><TD WIDTH=50><p>Name</p></TD><TD>
<INPUT TYPE=text NAME="name" SIZE=20 MAXLENGTH=50 VALUE="<?=$HTTP_COOKIE_VARS["hboard10_name"]?>">&nbsp;</TD></TR>

<TR><TD>Mail</TD><TD><INPUT TYPE=text NAME="email" SIZE=32 MAXLENGTH=255 VALUE="<?=$HTTP_COOKIE_VARS["hboard10_email"]?>">&nbsp;</TD></TR>
<TR><TD>URL(*)</TD><TD><INPUT TYPE=text NAME="homepage" SIZE=32 MAXLENGTH=255 VALUE="
<?php
if($HTTP_COOKIE_VARS["hboard10_homepage"] == "") {
	echo "http://"; }
else {
	echo $HTTP_COOKIE_VARS["hboard10_homepage"]; }
?>">&nbsp;</TD></TR>

<TR><TD>Password</TD><TD>
<INPUT TYPE=password NAME="passwd" SIZE=9 MAXLENGTH=16>&nbsp;</TD></TR>

<TR><TD>Icon</TD><TD>
<p>
<select name="icon" onChange="drawImage(this, document.icon)">
<option value="none.jpg">( )</option>
<option value="none.jpg">--------------------</option>
<?php
//   ܾ.. (..php.net ܾ. .)
if ($handle = opendir('db/ico/')) {
    while (false !== ($file = readdir($handle))) { 
        if ($file != "." && $file != ".." && $file != "none.jpg" && $file != "index.html") { 
            echo "<option value='" .$file ."'>" .$file ."</option>\n"; 
        }
    }
    closedir($handle);
}

?>
</select>&nbsp;</p>
</TD></TR>
</TABLE>

<TABLE BORDER=0 CELLPADDING=0 CELLSPACING=0>
<TR><TD height="90"><TEXTAREA NAME="ne" ROWS="6" COLS=45></TEXTAREA></TD></TR>
</TABLE>

<TABLE BORDER=0 CELLPADDING=0 CELLSPACING=0>
<TR><TD>&nbsp;</TD></TR>
</TABLE>

<TABLE BORDER=0 CELLPADDING=0 CELLSPACING=0 WIDTH="100%">
<TR><TD ALIGN=CENTER>
<INPUT name="submit_btn" TYPE=button VALUE="Submit" ONCLICK="checkvalue();" accesskey=s>&nbsp;<INPUT name="reset_btn" TYPE=reset VALUE="Reset"> 
<a href="list.php?page=<?=$page ."#" .$article?>">[ǵư]</a>
</TD></TR>
</TABLE>

</td></tr>
</table>
</TD>

<TD WIDTH="268" HEIGHT="220"><center>
<IMG border='0' name='icon' SRC='skin/<?=$admin_data[skin]?>/none.jpg' alt='Icon Preview'></center>
</TD></TR></TABLE>
</form>
</center>
</td></tr>
</table>
</center>

<center>
<?php
 PrintArticle($article,$article,false);
 echo "</center>";
}
PrintFooter();
?>

==> hboard-1.0.1.tar.gz: hboard/comment.php <==
<?php

/* EtchiBoard Version 1.0
     comment.php
     http://etchibbs.kldp.net */

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

include ("lib/admin.inc"); //  ȯ漳
include ("lib/headfoot.inc"); //  /ϴ
include ("lib/list.inc"); //   function
include ("lib/message.inc"); // ޽ function

PrintHeader();

if(!$article) {
 PrintMessage("<b>Խù  ϴ.</b><br>comment.php?article=[ȣ]  Էϼ.", "error");
}
else {
?>
<center>

<Script Language="JavaScript" Type="">
function imagesel(sel)
{
var src;
src = sel.options[sel.selectedIndex].value

if(sel.options[sel.selectedIndex].value == "none.jpg") {
  src = "skin/<?php echo $admin_data[skin]?>/"+src
}
else {
  src = "db/ico/"+src
}

 return src;
}

function drawImage(sel,i)
{
i.src = imagesel(sel)
i.alt = "Icon Preview";
}

function checkvalue() {
		if(document.inputform.name.value == ""){
			alert("ۼ ̸  ּ.");
			document.inputform.name.focus();
			return true;
		}
		else if(document.inputform.ne.value == ""){
			alert("ǰ߱  Է ּ.");
			document.inputform.ne.focus();
			return true;
		}
		else if(document.inputform.passwd.value == ""){
			alert("йȣ Է ּ.");
			document.inputform.passwd.focus();
			return true;
		}
		else{
			document.inputform.submit();
		}
}
</Script>

<table align="center" cellpadding="0" cellspacing="0" width="640">
<tr><td width="640" height="20">
<table cellpadding="0" cellspacing="0" width="100%">
<tr><td width="17" height="25" background="skin/<?php echo $admin_data[skin]?>/title_bg.gif">
<p align="center">
<img src="skin/<?php echo $admin_data[skin]?>/write.gif" width="14" height="20" border="0" alt="write.gif">
</p></td><td width="674" height="20" background="skin/<?php echo $admin_data[skin]?>/title_bg.gif">
<p><font color="<?php echo $skin[sfont2_color]?>">&nbsp;<b><?php echo $article?> Խù ǰ </b></font></p>
</td></tr>
</table>
</td></tr>

<tr>
<td width="640">

<center>
<form name="inputform" target="_self" method="post" action="post_comment.php" ENCTYPE="multipart/form-data" onsubmit="this.submit_btn.disabled=true">

<input type=hidden name=article value=<?php echo $article?>>
<input type=hidden name=page value=<?php echo $page?>>

<TABLE border=1 width="639" cellspacing=0 cellpadding=7 bgcolor="<?php echo $skin[image_table_bgcolor]?>">
<TR ALIGN=CENTER><TD width="337">
<table border=0 cellpadding=0 cellspacing=0><tr><td>
<TABLE BORDER=0 CELLPADDING=0 CELLSPACING=0>

<TR><TD WIDTH=50><p>Name</p></TD><TD>
<INPUT TYPE=text NAME="name" SIZE=20 MAXLENGTH=30 VALUE="<?php echo $HTTP_COOKIE_VARS["hboard10_name"]?>">&nbsp;</TD></TR>

<TR><TD>Mail</TD><TD><INPUT TYPE=text NAME="email" SIZE=32 MAXLENGTH=100 VALUE="<?php echo $HTTP_COOKIE_VARS["hboard10_email"]?>">&nbsp;</TD></TR>
<TR><TD>URL(*)</TD><TD><INPUT TYPE=text NAME="homepage" SIZE=32 MAXLENGTH=255 VALUE="
<?php
if($HTTP_COOKIE_VARS["hboard10_homepage"] == "") {
	echo "http://"; }
else {
	echo $HTTP_COOKIE_VARS["hboard10_homepage"]; }
?>">&nbsp;</TD></TR>

<TR><TD>Password</TD><TD>
<INPUT TYPE=password NAME="passwd" SIZE=9 MAXLENGTH=30>&nbsp;</TD></TR>

<TR><TD>Icon</TD><TD>
<p>
<select name="icon" onChange="drawImage(this, document.icon)">
<option value="none.jpg">( )</option>
<option value="none.jpg">--------------------</option>
<?php
//   ܾ.. (..php.net ܾ. .)
if ($handle = opendir('db/ico/')) {
    while (false !== ($file = readdir($handle))) { 
        if ($file != "." && $file != ".." && $file != "none.jpg" && $file != "index.html") { 
            echo "<option value='" .$file ."'>" .$file ."</option>\n"; 
        }
    }
    closedir($handle);
}

?>
</select>&nbsp;</p>
</TD></TR>
</TABLE>

<TABLE BORDER=0 CELLPADDING=0 CELLSPACING=0>
<TR><TD height="90"><TEXTAREA NAME="ne" ROWS="6" COLS=45></TEXTAREA></TD></TR>
</TABLE>

<TABLE BORDER=0 CELLPADDING=0 CELLSPACING=0>
<TR><TD>&nbsp;</TD></TR>
</TABLE>

<TABLE BORDER=0 CELLPADDING=0 CELLSPACING=0 WIDTH="100%">
<TR><TD ALIGN=CENTER>
<INPUT name="submit_btn" TYPE=button VALUE="Submit" ONCLICK="checkvalue();" accesskey=s>&nbsp;<INPUT name="reset_btn" TYPE=reset VALUE="Reset"> 
<a href="list.php?page=<?php echo $page ."#" .$article?>">[ǵư]</a>
</TD></TR>
</TABLE>

</td></tr>
</table>
</TD>

<TD WIDTH="268" HEIGHT="220"><center>
<IMG border='0' name='icon' SRC='skin/<?php echo $admin_data[skin]?>/none.jpg' alt='Icon Preview'></center>
</TD></TR></TABLE>
</form>
</center>
</td></tr>
</table>
</center>

<center>
<?php
 PrintArticle($article,$article,false);
 echo "</center>";
}
PrintFooter();
?>
